Page class

Constructors

Page(String title, Widget child, {bool withScaffold = true, bool padding = true, bool showLog = false})
Page.builder(String title, WidgetBuilder builder, {bool withScaffold = true, bool padding = true, bool showLog = false})

Properties

builder ↔ WidgetBuilder
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
padding ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showLog ↔ bool
getter/setter pair
title ↔ String
getter/setter pair
withScaffold ↔ bool
getter/setter pair

Methods

build(BuildContext context) → Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openPage<T>(BuildContext context) → Future<T?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited